==> ToolChain_STM32_1.0.50.tar.bz: ToolChain_STM32_1.0.50/Template/examples/example_radio_serial.h <==
#ifndef EXAMPLE_RADIO_SERIAL
#define EXAMPLE_RADIO_SERIAL

/*{ ExampleRadio.h *******************************************************
 
  Initializes first radio and periodically transmits data.
  Received data is echoes via TTC_USART1.

}*/
//{ Includes *************************************************************

// Basic set of helper functions
#include "ttc_basic.h"
#include "ttc_gpio.h"
#include "ttc_task.h"
#include "ttc_random.h"
#include "ttc_watchdog.h"
#include "ttc_radio.h"
#include "ttc_usart.h"
#include "ttc_string.h"

//} Includes
//{ Defines/ TypeDefs ****************************************************


#ifndef TTC_TX
  #ifdef TTC_LED1
    #define TTC_TX TTC_LED1
  #else
    #warning TTC_TX not defined!
  #endif
#endif
#ifndef TTC_RX
  #ifdef TTC_LED2
    #define TTC_RX TTC_LED2
  #else
    #warning TTC_RX not defined!
  #endif
#endif

//} Defines
//{ Structures/ Enums ****************************************************

//} Structures/ Enums
//{ Global Variables *****************************************************



//} Global Variables
//{ Function prototypes **************************************************

// basic hardware intialization
void example_radio_serial_init();

// main entry: initializes hardware + spawns all threads
// returns immediately
void example_radio_serial_start();

// observes every outgoing packet
void txFunction_R1(ttc_radio_generic_t* RadioCfg, u8_t Size, const u8_t* Buffer);

// handles incoming packets
ttc_memory_block_t* rxFunction_R1(ttc_radio_generic_t* RadioCfg, ttc_memory_block_t* Block, u8_t RSSI, u8_t TargetAddress);

//receive function for uart
ttc_memory_block_t* receiveData(ttc_usart_generic_t* USART_Generic, ttc_memory_block_t* Data);

//
/** function to reload the Watchdog
 * @param Index logical index of the task that has called this watchdog.
 */
void reloadWatchdog(u8_t Index);
//} Function prototypes

#endif //EXAMPLE_RADIO

==> ToolChain_STM32_1.0.52.tar.bz: ToolChain_STM32_1.0.52/Template/examples/example_radio_serial.h <==
#ifndef EXAMPLE_RADIO_SERIAL
#define EXAMPLE_RADIO_SERIAL

/*{ ExampleRadio.h *******************************************************
 
  Initializes first radio and periodically transmits data.
  Received data is echoes via TTC_USART1.

}*/
//{ Includes *************************************************************

// Basic set of helper functions
#include "../common/ttc_basic.h"
#include "../common/ttc_gpio.h"
#include "../common/ttc_task.h"
#include "../common/ttc_random.h"
#include "../common/ttc_watchdog.h"
#include "../common/ttc_radio.h"
#include "../common/ttc_usart.h"
#include "../common/ttc_string.h"

//} Includes
//{ Defines/ TypeDefs ****************************************************


#ifndef TTC_TX
  #ifdef TTC_LED1
    #define TTC_TX TTC_LED1
  #else
    #warning TTC_TX not defined!
  #endif
#endif
#ifndef TTC_RX
  #ifdef TTC_LED2
    #define TTC_RX TTC_LED2
  #else
    #warning TTC_RX not defined!
  #endif
#endif

//} Defines
//{ Structures/ Enums ****************************************************

//} Structures/ Enums
//{ Global Variables *****************************************************



//} Global Variables
//{ Function prototypes **************************************************

// basic hardware intialization
void example_radio_serial_init();

// main entry: initializes hardware + spawns all threads
// returns immediately
void example_radio_serial_start();

// observes every outgoing packet
void txFunction_R1(ttc_radio_generic_t* RadioCfg, u8_t Size, const u8_t* Buffer);

// handles incoming packets
ttc_memory_block_t* rxFunction_R1(ttc_radio_generic_t* RadioCfg, ttc_memory_block_t* Block, u8_t RSSI, u8_t TargetAddress);

//receive function for uart
ttc_memory_block_t* receiveData(ttc_usart_generic_t* USART_Generic, ttc_memory_block_t* Data);

//
/** function to reload the Watchdog
 * @param Index logical index of the task that has called this watchdog.
 */
void reloadWatchdog(u8_t Index);
//} Function prototypes

#endif //EXAMPLE_RADIO
